@@ -708,16 +708,13 @@ subview<eT>::for_each(functor F)
   {
   arma_extra_debug_sigprint();
   
-  const uword local_n_cols = n_cols;
-  const uword local_n_rows = n_rows;
-  
   Mat<eT>& X = const_cast< Mat<eT>& >(m);
   
-  if(local_n_rows == 1)
+  if(n_rows == 1)
     {
     const uword urow          = aux_row1;
     const uword start_col     = aux_col1;
-    const uword end_col_plus1 = start_col + local_n_cols;
+    const uword end_col_plus1 = start_col + n_cols;
     
     for(uword ucol = start_col; ucol < end_col_plus1; ++ucol)
       {
@@ -729,8 +726,47 @@ subview<eT>::for_each(functor F)
     const uword start_col = aux_col1;
     const uword start_row = aux_row1;
     
-    const uword end_col_plus1 = start_col + local_n_cols;
-    const uword end_row_plus1 = start_row + local_n_rows;
+    const uword end_col_plus1 = start_col + n_cols;
+    const uword end_row_plus1 = start_row + n_rows;
+    
+    for(uword ucol = start_col; ucol < end_col_plus1; ++ucol)
+    for(uword urow = start_row; urow < end_row_plus1; ++urow)
+      {
+      F( X.at(urow, ucol) );
+      }
+    }
+  }
+
+
+
+template<typename eT>
+template<typename functor>
+inline
+void
+subview<eT>::for_each(functor F) const
+  {
+  arma_extra_debug_sigprint();
+  
+  const Mat<eT>& X = m;
+  
+  if(n_rows == 1)
+    {
+    const uword urow          = aux_row1;
+    const uword start_col     = aux_col1;
+    const uword end_col_plus1 = start_col + n_cols;
+    
+    for(uword ucol = start_col; ucol < end_col_plus1; ++ucol)
+      {
+      F( X.at(urow, ucol) );
+      }
+    }
+  else
+    {
+    const uword start_col = aux_col1;
+    const uword start_row = aux_row1;
+    
+    const uword end_col_plus1 = start_col + n_cols;
+    const uword end_row_plus1 = start_row + n_rows;
     
     for(uword ucol = start_col; ucol < end_col_plus1; ++ucol)
     for(uword urow = start_row; urow < end_row_plus1; ++urow)
@@ -751,16 +787,13 @@ subview<eT>::transform(functor F)
   {
   arma_extra_debug_sigprint();
   
-  const uword local_n_cols = n_cols;
-  const uword local_n_rows = n_rows;
-  
   Mat<eT>& X = const_cast< Mat<eT>& >(m);
   
-  if(local_n_rows == 1)
+  if(n_rows == 1)
     {
     const uword urow          = aux_row1;
     const uword start_col     = aux_col1;
-    const uword end_col_plus1 = start_col + local_n_cols;
+    const uword end_col_plus1 = start_col + n_cols;
     
     for(uword ucol = start_col; ucol < end_col_plus1; ++ucol)
       {
@@ -772,8 +805,8 @@ subview<eT>::transform(functor F)
     const uword start_col = aux_col1;
     const uword start_row = aux_row1;
     
-    const uword end_col_plus1 = start_col + local_n_cols;
-    const uword end_row_plus1 = start_row + local_n_rows;
+    const uword end_col_plus1 = start_col + n_cols;
+    const uword end_row_plus1 = start_row + n_rows;
     
     for(uword ucol = start_col; ucol < end_col_plus1; ++ucol)
     for(uword urow = start_row; urow < end_row_plus1; ++urow)
@@ -794,16 +827,13 @@ subview<eT>::imbue(functor F)
   {
   arma_extra_debug_sigprint();
   
-  const uword local_n_cols = n_cols;
-  const uword local_n_rows = n_rows;
-  
   Mat<eT>& X = const_cast< Mat<eT>& >(m);
   
-  if(local_n_rows == 1)
+  if(n_rows == 1)
     {
     const uword urow          = aux_row1;
     const uword start_col     = aux_col1;
-    const uword end_col_plus1 = start_col + local_n_cols;
+    const uword end_col_plus1 = start_col + n_cols;
     
     for(uword ucol = start_col; ucol < end_col_plus1; ++ucol)
       {
@@ -815,8 +845,8 @@ subview<eT>::imbue(functor F)
     const uword start_col = aux_col1;
     const uword start_row = aux_row1;
     
-    const uword end_col_plus1 = start_col + local_n_cols;
-    const uword end_row_plus1 = start_row + local_n_rows;
+    const uword end_col_plus1 = start_col + n_cols;
+    const uword end_row_plus1 = start_row + n_rows;
     
     for(uword ucol = start_col; ucol < end_col_plus1; ++ucol)
     for(uword urow = start_row; urow < end_row_plus1; ++urow)
@@ -2015,6 +2045,138 @@ subview<eT>::each_row(const Base<uword,T1>& indices)
 
 
 
+#if defined(ARMA_USE_CXX11)
+  
+  //! apply a lambda function to each column, where each column is interpreted as a column vector
+  template<typename eT>
+  inline
+  void
+  subview<eT>::each_col(const std::function< void(Col<eT>&) >& F)
+    {
+    arma_extra_debug_sigprint();
+    
+    for(uword ii=0; ii < n_cols; ++ii)
+      {
+      Col<eT> tmp(colptr(ii), n_rows, false, true);
+      F(tmp);
+      }
+    }
+  
+  
+  
+  template<typename eT>
+  inline
+  void
+  subview<eT>::each_col(const std::function< void(const Col<eT>&) >& F) const
+    {
+    arma_extra_debug_sigprint();
+    
+    for(uword ii=0; ii < n_cols; ++ii)
+      {
+      const Col<eT> tmp(colptr(ii), n_rows, false, true);
+      F(tmp);
+      }
+    }
+  
+  
+  
+  //! apply a lambda function to each row, where each row is interpreted as a row vector
+  template<typename eT>
+  inline
+  void
+  subview<eT>::each_row(const std::function< void(Row<eT>&) >& F)
+    {
+    arma_extra_debug_sigprint();
+    
+    podarray<eT> array1(n_cols);
+    podarray<eT> array2(n_cols);
+    
+    Row<eT> tmp1( array1.memptr(), n_cols, false, true );
+    Row<eT> tmp2( array2.memptr(), n_cols, false, true );
+    
+    eT* tmp1_mem = tmp1.memptr();
+    eT* tmp2_mem = tmp2.memptr();
+    
+    uword ii, jj;
+    
+    for(ii=0, jj=1; jj < n_rows; ii+=2, jj+=2)
+      {
+      for(uword col_id = 0; col_id < n_cols; ++col_id)
+        {
+        const eT* col_mem = colptr(col_id);
+        
+        tmp1_mem[col_id] = col_mem[ii];
+        tmp2_mem[col_id] = col_mem[jj];
+        }
+      
+      F(tmp1);
+      F(tmp2);
+      
+      for(uword col_id = 0; col_id < n_cols; ++col_id)
+        {
+        eT* col_mem = colptr(col_id);
+        
+        col_mem[ii] = tmp1_mem[col_id];
+        col_mem[jj] = tmp2_mem[col_id];
+        }
+      }
+    
+    if(ii < n_rows)
+      {
+      tmp1 = (*this).row(ii);
+      
+      F(tmp1);
+      
+      (*this).row(ii) = tmp1;
+      }
+    }
+  
+  
+  
+  template<typename eT>
+  inline
+  void
+  subview<eT>::each_row(const std::function< void(const Row<eT>&) >& F) const
+    {
+    arma_extra_debug_sigprint();
+    
+    podarray<eT> array1(n_cols);
+    podarray<eT> array2(n_cols);
+    
+    Row<eT> tmp1( array1.memptr(), n_cols, false, true );
+    Row<eT> tmp2( array2.memptr(), n_cols, false, true );
+    
+    eT* tmp1_mem = tmp1.memptr();
+    eT* tmp2_mem = tmp2.memptr();
+    
+    uword ii, jj;
+    
+    for(ii=0, jj=1; jj < n_rows; ii+=2, jj+=2)
+      {
+      for(uword col_id = 0; col_id < n_cols; ++col_id)
+        {
+        const eT* col_mem = colptr(col_id);
+        
+        tmp1_mem[col_id] = col_mem[ii];
+        tmp2_mem[col_id] = col_mem[jj];
+        }
+      
+      F(tmp1);
+      F(tmp2);
+      }
+    
+    if(ii < n_rows)
+      {
+      tmp1 = (*this).row(ii);
+      
+      F(tmp1);
+      }
+    }
+  
+#endif
+
+
+
 //! creation of diagview (diagonal)
 template<typename eT>
 inline
